@@ -15,8 +15,8 @@ class DjangoSignalEventProjector(EventProjector):
         message = Message(
             id=id,
             occurred_on=datetime.datetime.now(tz=datetime.timezone.utc),
-            event_type=event.__class__.__name__,
-            event=event,
+            event=event.__class__.__name__,
+            data=event,
             object_id=str(event.object_id),
         )
         fractal_event_signal.send(sender=self.__class__, message=message)
